import type { DId, DNestedChildren, DSize } from '../../utils';
import type { DFormControl } from '../form';
import type { DSelectItem } from '../select';
import type { AbstractTreeNode } from '../tree/node';
import React from 'react';
import { TREE_NODE_KEY } from '../tree/utils';
export interface DCascaderRef {
    updatePosition: () => void;
}
export declare type DSearchItem<V extends DId, T> = DSelectItem<V> & {
    [TREE_NODE_KEY]: AbstractTreeNode<V, T>;
};
export interface DCascaderItem<V extends DId> {
    label: string;
    value: V;
    loading?: boolean;
    disabled?: boolean;
}
export interface DCascaderProps<V extends DId, T extends DCascaderItem<V>> extends React.HTMLAttributes<HTMLDivElement> {
    dFormControl?: DFormControl;
    dList: DNestedChildren<T>[];
    dModel?: V | null | V[];
    dVisible?: boolean;
    dPlaceholder?: string;
    dSize?: DSize;
    dLoading?: boolean;
    dSearchable?: boolean;
    dClearable?: boolean;
    dDisabled?: boolean;
    dMultiple?: boolean;
    dOnlyLeafSelectable?: boolean;
    dCustomItem?: (item: DNestedChildren<T>) => React.ReactNode;
    dCustomSelected?: (select: DNestedChildren<T>) => string;
    dCustomSearch?: {
        filter?: (value: string, item: DNestedChildren<T>) => boolean;
        sort?: (a: DNestedChildren<T>, b: DNestedChildren<T>) => number;
    };
    dPopupClassName?: string;
    dInputProps?: React.InputHTMLAttributes<HTMLInputElement>;
    dInputRef?: React.Ref<HTMLInputElement>;
    onModelChange?: (value: any, item: any) => void;
    onVisibleChange?: (visible: boolean) => void;
    afterVisibleChange?: (visible: boolean) => void;
    onSearch?: (value: string) => void;
    onClear?: () => void;
    onFirstFocus?: (value: V, item: DNestedChildren<T>) => void;
}
declare function Cascader<V extends DId, T extends DCascaderItem<V>>(props: DCascaderProps<V, T>, ref: React.ForwardedRef<DCascaderRef>): JSX.Element | null;
export declare const DCascader: <V extends DId, T extends DCascaderItem<V>>(props: DCascaderProps<V, T> & React.RefAttributes<DCascaderRef>) => ReturnType<typeof Cascader>;
export {};
